[galaxy-commits] commit/galaxy-central: jgoecks: Trackster: bug fix when padding tiles for display.

Bitbucket commits-noreply at bitbucket.org
Wed Jan 11 14:19:37 EST 2012


1 new commit in galaxy-central:


https://bitbucket.org/galaxy/galaxy-central/changeset/831237b1a552/
changeset:   831237b1a552
user:        jgoecks
date:        2012-01-11 20:19:27
summary:     Trackster: bug fix when padding tiles for display.
affected #:  1 file

diff -r b716dc5d0e0eea1f8414cc75743852c02800b0d6 -r 831237b1a55211232eff0daf19501933748f0523 static/scripts/trackster.js
--- a/static/scripts/trackster.js
+++ b/static/scripts/trackster.js
@@ -2511,11 +2511,13 @@
     // Attribute init.
     Tile.call(this, track, index, resolution, canvas, data);
     this.mode = mode;
-    this.message = message;
     this.feature_mapper = feature_mapper;
+    this.has_icons = false;
     
     // Add message + action icons to tile's html.
     if (this.message || !all_slotted) {
+        this.has_icons = true;
+        
         var 
             tile = this;
             canvas = this.html_elt.children()[0],
@@ -3145,21 +3147,20 @@
         var track = this;
                                 
         //
         // If some tiles have messages, set padding of tiles without messages
         // so features and rows align.
         //
-        var messages_to_show = false;
+        var icons_present = false;
         for (var tile_index = 0; tile_index < tiles.length; tile_index++) {
-            if (tiles[tile_index].message) {
-                messages_to_show = true;
+            if (tiles[tile_index].has_icons) {
+                icons_present = true;
                 break;
             }
         }
-        if (messages_to_show) {
+        if (icons_present) {
             for (var tile_index = 0; tile_index < tiles.length; tile_index++) {
                 tile = tiles[tile_index];
-                if (!tile.message) {
-                    // Need to align with other tile(s) that have message(s).
+                if (!tile.has_icons) {
+                    // Need to align with other tile(s) that have icons.
                     tile.html_elt.css("padding-top", ERROR_PADDING);
                 }
             }
@@ -3145,21 +3147,20 @@
                                 
         //
-        // If some tiles have messages, set padding of tiles without messages
-        // so features and rows align.
+        // If some tiles have icons, set padding of tiles without icons so features and rows align.
         //

Repository URL: https://bitbucket.org/galaxy/galaxy-central/

--

This is a commit notification from bitbucket.org. You are receiving
this because you have the service enabled, addressing the recipient of
this email.


More information about the galaxy-commits mailing list